Learn R Programming

iSubGen (version 1.0.5)

read.scaling.factors: Read scaling factors from file

Description

Read scaling factors from file

Usage

read.scaling.factors(scaling.factor.files.dir,data.types);

Value

a list with a key \"center\" list and a key \"scale\" list. The center and scale list keys match the data.matrices list keys

Arguments

scaling.factor.files.dir

the directory where the files were saved

data.types

a vector of the data types with saved scaling factors

Author

Natalie Fox

Details

One scale and one center file is saved per data type

Examples

Run this code

# Get the path for the scaling provided in this R package
example.molecular.data.dir <- paste0(path.package('iSubGen'),'/exdata/');

# Example #1: reading scaling factors for a single data type
scaling.factors <- read.scaling.factors(example.molecular.data.dir, 'cna');

# Example #2: reading scaling factors for multiple data types
scaling.factors <- read.scaling.factors(example.molecular.data.dir, c('cna','snv','methy'));

Run the code above in your browser using DataLab